Stan Math Library: stan/math/fwd/mat/fun/mdivide_left_ldlt.hpp Source File

| Stan Math Library 2.10.0 reverse mode automatic differentiation

- Main Page
- Modules
- Namespaces
- Classes
- Files

- File List
- File Members

mdivide_left_ldlt.hpp
Go to the documentation of this file.
1 #ifndef STAN_MATH_FWD_MAT_FUN_MDIVIDE_LEFT_LDLT_HPP
2 #define STAN_MATH_FWD_MAT_FUN_MDIVIDE_LEFT_LDLT_HPP
3
4 #include <stan/math/prim/mat/fun/Eigen.hpp>
5 #include <stan/math/prim/mat/fun/LDLT_factor.hpp>
6 #include <stan/math/prim/mat/err/check_multiplicable.hpp>
7 #include <stan/math/prim/mat/fun/promote_common.hpp>
8 #include <stan/math/prim/mat/fun/mdivide_left_ldlt.hpp>
9 #include <stan/math/fwd/mat/fun/to_fvar.hpp>
10 #include <boost/math/tools/promotion.hpp>
11
12 namespace stan {
13 namespace math {
14
23 template <int R1, int C1, int R2, int C2, typename T2>
24 inline Eigen::Matrix<fvar<T2>, R1, C2>
25 mdivide_left_ldlt(const stan::math::LDLT_factor<double, R1, C1> &A,
26 const Eigen::Matrix<fvar<T2>, R2, C2> &b) {
27 stan::math::check_multiplicable("mdivide_left_ldlt",
28 "A", A,
29 "b", b);
30
31 Eigen::Matrix<T2, R2, C2> b_val(b.rows(), b.cols());
32 Eigen::Matrix<T2, R2, C2> b_der(b.rows(), b.cols());
33 for (int i = 0; i < b.rows(); i++)
34 for (int j = 0; j < b.cols(); j++) {
35 b_val(i, j) = b(i, j).val_;
36 b_der(i, j) = b(i, j).d_;
37 }
38
39 return to_fvar(mdivide_left_ldlt(A, b_val),
40 mdivide_left_ldlt(A, b_der));
41 }
42 }
43 }
44 #endif
check_multiplicable.hpp
stan
Definition: log_sum_exp.hpp:8
promote_common.hpp
stan::math::to_fvar
std::vector< fvar< T > > to_fvar(const std::vector< T > &v)
Definition: to_fvar.hpp:14
stan::math::LDLT_factor
Definition: LDLT_factor.hpp:18
LDLT_factor.hpp
stan::math::mdivide_left_ldlt
Eigen::Matrix< fvar< T2 >, R1, C2 > mdivide_left_ldlt(const stan::math::LDLT_factor< double, R1, C1 > &A, const Eigen::Matrix< fvar< T2 >, R2, C2 > &b)
Returns the solution of the system Ax=b given an LDLT_factor of A.
Definition: mdivide_left_ldlt.hpp:25
stan::math::check_multiplicable
bool check_multiplicable(const char *function, const char *name1, const T1 &y1, const char *name2, const T2 &y2)
Return true if the matrices can be multiplied.
Definition: check_multiplicable.hpp:33
Eigen.hpp
mdivide_left_ldlt.hpp
to_fvar.hpp
stan::math::fvar
Definition: fvar.hpp:13

[ Stan Home Page ] © 2011–2016, Stan Development Team.